/*
Controller.m - SMS Framework
Copyright (C) 2005, Tim Ellis

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#import "SMS-Bundled/SMS.h"
#import "Controller.h"

@implementation Controller

- init {
	self = [super init];
	smsInterface = [[SMS alloc] init];
	return self;
}

- (IBAction)decode:(id)sender {
	SMSObject *sms = [[SMSObject alloc] init];
	sms = [smsInterface decode:[fieldMessage stringValue]];
	if([disableOutput isEnabled] == FALSE) [self displaySmsInfo:sms];
	[sms release];
}

- (void) displaySmsInfo:(SMSObject*)sms {
	NSString *returnString = [NSString stringWithFormat:
		@"\nService Type: %@\nService NPI: %@\nService Number: %@\nReply Path Present: %@\nHeader Present: %@\nStatus Report Sent: %@\nMore Messages (0 if more): %@\nMessage Type Indicator: %@\nSender Type: %@\nSender NPI: %@\nSender Number: %@\nDCS Type: %@\nMessage Alphabet: %@\nMessage Class: %@\nMessage Compression: %@\nMessage Class Validity: %@\nIndication Active: %@\nIndication Type: %@\nTimestamp: %@\nHeader: %@\nData: %@",
		[self stringForToaType:[[[sms smscInfo] objectForKey:@"type"] intValue]],
		[self stringForToaNpi:[[[sms smscInfo] objectForKey:@"npi"] intValue]],
		[[sms smscInfo] objectForKey:@"number"],
		[[sms firstOctetInfo] objectForKey:@"replypath"],
		[[sms firstOctetInfo] objectForKey:@"udhi"],
		[[sms firstOctetInfo] objectForKey:@"sri"],
		[[sms firstOctetInfo] objectForKey:@"mms"],
		[[sms firstOctetInfo] objectForKey:@"mti"],
		[self stringForToaType:[[[sms senderInfo] objectForKey:@"type"] intValue]],
		[self stringForToaNpi:[[[sms senderInfo] objectForKey:@"npi"] intValue]],
		[[sms senderInfo] objectForKey:@"number"],
		[[sms tpDcsInfo] objectForKey:@"dcstype"],
		[[sms tpDcsInfo] objectForKey:@"msgalphabet"],
		[[sms tpDcsInfo] objectForKey:@"msgclass"],
		[[sms tpDcsInfo] objectForKey:@"msgcompression"],
		[[sms tpDcsInfo] objectForKey:@"msgclassvalidity"],
		[[sms tpDcsInfo] objectForKey:@"indactivity"],
		[[sms tpDcsInfo] objectForKey:@"indtype"],
		[[sms timestamp] description],
		[[sms messageAndHeader] objectForKey:@"header"],
		[[sms messageAndHeader] objectForKey:@"data"]];
	if([[fieldDisplay string] length] > 15000) {
		[fieldDisplay replaceCharactersInRange:NSMakeRange(0, ([[fieldDisplay string] length] / 4)) withString:@""];
		[fieldDisplayOther replaceCharactersInRange:NSMakeRange(0, ([[fieldDisplayOther string] length] / 4)) withString:@""];
	}
    [fieldDisplay replaceCharactersInRange:NSMakeRange([[fieldDisplay string] length], 0) withString:returnString];
	[fieldDisplay scrollRangeToVisible:NSMakeRange([[fieldDisplay string] length], 0)];
    [fieldDisplayOther replaceCharactersInRange:NSMakeRange([[fieldDisplayOther string] length], 0) withString:returnString];
	[fieldDisplayOther scrollRangeToVisible:NSMakeRange([[fieldDisplayOther string] length], 0)];
}

- (NSString*)stringForToaNpi:(int)num {
	switch(num) {
		case kToaNpiISDNTelephone:
			return @"ISDN/Telephone";
		case kToaNpiData:
			return @"Data";
		case kToaNpiTelex:
			return @"Telex";
		case kToaNpiNational:
			return @"National";
		case kToaNpiPrivate:
			return @"Private";
		case kToaNpiErmes:
			return @"Ermes";
		case kToaNpiReserved:
			return @"Reserved";
		case kToaNpiUnknown:
			return @"Unknown";
		default:
			return nil;
	}
}

- (NSString*)stringForToaType:(int)num {
	switch(num) {
		case kToaTypeInternational:
			return @"International";
		case kToaTypeNational:
			return @"National";
		case kToaTypeNetwork:
			return @"Network";
		case kToaTypeSubscriber:
			return @"Subscriber";
		case kToaTypeAlphanumeric:
			return @"Alphanumeric";
		case kToaTypeAbbbreviated:
			return @"Abbreviated";
		case kToaTypeReserved:
			return @"Reserved";
		case kToaTypeUnknown:
			return @"Unknown";
		default:
			return nil;
	}
}

@end
